@@ -2,63 +2,62 @@ package Blosxom::Header;
 use 5.008_001;
 use strict;
 use warnings;
-use List::Util qw(first);
+use Exporter 'import';
+use List::Util 'first';
 
-our $VERSION = '0.01013';
+our $VERSION   = '0.01014';
+our @EXPORT_OK = qw( get_header set_header remove_header has_header );
 
 sub new {
-    my ( $class, $header_ref ) = @_;
-    bless { header_ref => $header_ref }, $class;
+    require Blosxom::Header::Object;
+    my $header_ref = $_[1];
+
+    Blosxom::Header::Object->new(
+        get    => sub { get_header( $header_ref, @_ )    },
+        set    => sub { set_header( $header_ref, @_ )    },
+        has    => sub { has_header( $header_ref, @_ )    },
+        remove => sub { remove_header( $header_ref, @_ ) },
+    );
 }
 
-sub get {
-    my $self       = shift;
+sub get_header {
+    my $header_ref = shift;
     my $key        = _lc( shift );
-    my $header_ref = $self->{header_ref};
 
-    # if any key matches $key, return the value
-    my $value;
+    # if any key matches $key, returns the value
     while ( my ( $k, $v ) = each %{ $header_ref } ) {
-        next unless _lc( $k ) eq $key;
-        $value = $v;
-        last;
+        return $v if _lc( $k ) eq $key;
     }
 
-    return $value;
-}
-
-sub set {
-    my $self       = shift;
-    my $key        = shift;
-    my $value      = shift;
-    my $header_ref = $self->{header_ref};
-
-    # if any key matches $key, replaces the value with $value
-    my $k = first { _lc( $_ ) eq _lc( $key ) } keys %{ $header_ref };
-    $header_ref->{ $k || $key } = $value;
-
     return;
 }
 
-sub exists {
-    my $self   = shift;
-    my $key    = _lc( shift );
-    my $exists = 0;
+sub set_header {
+    my ( $header_ref, $key, $value ) = @_;
 
-    # if any key matches $key, returns true
-    for my $k ( keys %{ $self->{header_ref} } ) {
-        next unless _lc( $k ) eq $key;
-        $exists = 1;
-        last;
-    }
+    # if any key matches $key, replaces the value with $value
+    my @keys      = keys %{ $header_ref };
+    my $first_key = first { _lc( $_ ) eq _lc( $key ) } @keys;
+    $header_ref->{ $first_key || $key } = $value;
 
-    return $exists;
+    return;
 }
 
-sub remove {
-    my $self       = shift;
+sub has_header {
+    my $header_ref = shift;
+    my $key        = _lc( shift );
+
+    # if any key matches $key, returns true
+    for my $k ( keys %{ $header_ref } ) {
+        return 1 if _lc( $k ) eq $key;
+    }
+
+    return 0;
+}
+
+sub remove_header {
+    my $header_ref = shift;
     my $key        = _lc( shift );
-    my $header_ref = $self->{header_ref};
 
     # deletes an element whose key matches $key
     my @keys = grep { _lc( $_ ) eq $key } keys %{ $header_ref };
@@ -71,10 +70,10 @@ sub remove {
 sub _lc {
     my $key = lc shift;
 
-    # get rid of an initial hyphen if exists
+    # get rid of an initial dash if exists
     $key =~ s{^\-}{};
 
-    # use hyphens instead of underbars
+    # use dashes instead of underscores
     $key =~ tr{_}{-};
 
     return $key;
@@ -92,18 +91,24 @@ Blosxom::Header - Missing interface to modify HTTP headers
 
   # blosxom.cgi
   package blosxom;
-  our $header = { -type => 'text/html' };
+  our $header = { foo => 'bar' };
 
   # plugins/foo
   package foo;
-  use Blosxom::Header;
+  use Blosxom::Header qw(get_header set_header has_header remove_header);
 
-  my $h     = Blosxom::Header->new($blosxom::header);
-  my $value = $h->get('type');
-  my $bool  = $h->exists('type');
+  # Functional interface
+  my $value = get_header( $blosxom::header, 'foo' );
+  my $bool  = has_header( $blosxom::header, 'foo' );
+  set_header( $blosxom::header, 'bar' => 'baz' );
+  remove_header( $blosxom::header, 'foo' );
 
-  $h->set( type => 'text/plain' );
-  $h->remove('type');
+  # OO interface
+  my $h     = Blosxom::Header->new( $blosxom::header );
+  my $value = $h->get('foo');
+  my $bool  = $h->has('foo');
+  $h->set( bar => 'baz' );
+  $h->remove('foo');
 
 =head1 DESCRIPTION
 
@@ -120,37 +125,67 @@ When plugin developers modify HTTP headers, they must write as follows:
 It's obviously bad practice.
 Blosxom misses the interface to modify them.
 
-This module allows you to modify them in an object-oriented way:
+This module provieds you an OO interface:
 
-  my $h = Blosxom::Header->new($blosxom::header);
-  $h->set(Status => '304 Not Modified');
+  use Blosxom::Header;
+  my $h = Blosxom::Header->new( $blosxom::header );
+  $h->set( 'Status' => '304 Not Modified' );
+
+or a functional one:
+
+  use Blosxom::Header qw(set_header);
+  set_header( $blosxom::header, 'Status' => '304 Not Modified' );
 
 You don't need to mind whether to put a hyphen before a key,
 nor whether to make a key lowercased or L<camelized|String::CamelCase>.
 
+=head2 SUBROUTINES
+
+The following are exported on demand.
+
+=over 4
+
+=item get_header( $blosxom::header, 'foo' )
+
+Returns a value of the specified HTTP header.
+
+=item set_header( $blosxom::header, 'foo' => 'bar' )
+
+Sets a value of the specified HTTP header.
+
+=item has_header( $blosxom::header, 'foo' )
+
+Returns a Boolean value telling whether the specified HTTP header exists.
+
+=item remove_header( $blosxom::header, 'foo' )
+
+Deletes the specified element from HTTP headers.
+
+=back
+
 =head2 METHODS
 
 =over 4
 
-=item $h = Blosxom::Header->new($blosxom::header)
+=item $h = Blosxom::Header->new( $blosxom::header )
 
 Creates a new Blosxom::Header object.
 
-=item $h->exists('foo')
+=item $h->has( 'foo' )
 
-Returns a Boolean value telling whether the specified HTTP header exists.
+A synonym for has_header.
 
-=item $h->get('foo')
+=item $h->get( 'foo' )
 
-Returns a value of the specified HTTP header.
+A synonym for get_header.
 
-=item $h->remove('foo')
+=item $h->remove( 'foo' )
 
-Deletes the specified element from HTTP headers.
+A synonym for remove_header.
 
-=item $h->set('foo' => 'bar')
+=item $h->set( 'foo' => 'bar' )
 
-Sets a value of the specified HTTP header.
+A synonym for set_header.
 
 =back
 
